# panoptipy

A Python Package for Static Code Quality Assessment. Use it to analyse your repos and assess their quality.

> ⚠️ Under development; use not currently recommended

![panoptipy logo](docs/logo.svg)
